@@ -9,7 +9,7 @@ use Child::Link::Parent;
 
 use Exporter 'import';
 
-our $VERSION = "0.011";
+our $VERSION = "0.013";
 our @PROCS;
 our @EXPORT_OK = qw/child/;
 
@@ -27,7 +27,8 @@ sub _clean_proc {
     my $class = shift;
     my ($proc) = @_;
     return unless $proc;
-    @PROCS = grep { $proc != $_ } @PROCS;
+    return unless @PROCS;
+    @PROCS = grep { $_ && $proc != $_ } @PROCS;
 }
 
 sub all_proc_pids {
@@ -255,7 +256,7 @@ The base class for IPC plugin link objects. This provides the IPC methods.
 
 =head1 HISTORY
 
-Most of this was part of L<Parrallel::Runner> intended for use in the L<Fennec>
+Most of this was part of L<Parallel::Runner> intended for use in the L<Fennec>
 project. Fennec is being broken into multiple parts, this is one such part.
 
 =head1 FENNEC PROJECT
